@@ -35,8 +35,6 @@
 
 #define CAMERA_ORIENTATION_FILE "/sys/devices/platform/gpio-switch/cam_turn/state"
 
-static Lum::Object::Prefs *prefs=new Lum::Object::Prefs();
-
 static gboolean cb_have_data(GstElement* /*element*/,
                              GstBuffer *buffer,
                              GstPad* /*pad*/,
@@ -56,8 +54,6 @@ VideoControl::VideoControl()
 {
   SetDestroyOnCleanup(false);
 
-  SetPrefs(::prefs);
-
   AttachModel(gstMsg);
   AttachModel(timer);
 }
@@ -189,7 +185,7 @@ void VideoControl::Layout()
                                 "video/x-raw-yuv,width=640,height=480 ! "
                                 "ffmpegcolorspace ! "
                                 "tee name=t ! "
-                                "queue ! " 
+                                "queue ! "
                                 "{ xvimagesink name=videosink }"
                                 "t. ! "
                                 "queue ! "
